GetSessionChallenge

Struct GetSessionChallenge 

pub struct GetSessionChallenge { /* private fields */ }
The Get Session Challenge command.

Implementations

Source

impl GetSessionChallenge

pub fn new(auth_type: AuthType, username: Option<&str>) -> Option<Self>

Create a new GetSessionChallenge command.

  • auth_type: the auth type to requests a session challenge for.
  • username: an optional username to request a session challenge for.

Will return None if username is longer than 16 bytes.

pub fn auth_type(&self) -> AuthType

The auth type to request a challenge for.

pub fn username(&self) -> &str

The username to request a session challenge for.