pub struct GetChannelAccess { /* private fields */ }Expand description
The Get Channel Access command.
This command is used to return whether a given channel is enabled or disabled, whether alerting is enabled or disabled for the entire channel, and under what system modes the channel can be accessed.
Reference: IPMI 2.0 Specification, Table 22-28
Implementations
Sourceimpl GetChannelAccess
impl GetChannelAccess
Sourcepub fn new(channel: Channel, access_type: ChannelAccessType) -> Self
pub fn new(channel: Channel, access_type: ChannelAccessType) -> Self
Create a new Get Channel Access command for channel.
Use access_type to specify whether to get the non-volatile or volatile
(currently active) settings.
Sourcepub fn non_volatile(channel: Channel) -> Self
pub fn non_volatile(channel: Channel) -> Self
Create a command to get the non-volatile (persistent) access settings.